@@ -13,8 +13,6 @@ use strict;
 use warnings;
 use utf8;
 
-use Kernel::System::VariableCheck qw(:all);
-
 use parent qw(Kernel::System::ProcessManagement::TransitionAction::Base);
 
 our @ObjectDependencies = (
@@ -52,15 +50,19 @@ sub new {
 
 =head2 Run()
 
-    Run Data
+Runs TransitionAction TicketOwnerSet.
 
-    my $TicketOwnerSetResult = $TicketOwnerSetActionObject->Run(
+    my $Success = $TicketOwnerSetActionObject->Run(
         UserID                   => 123,
+
+        # Ticket contains the result of TicketGet including dynamic fields
         Ticket                   => \%Ticket,   # required
         ProcessEntityID          => 'P123',
         ActivityEntityID         => 'A123',
         TransitionEntityID       => 'T123',
         TransitionActionEntityID => 'TA123',
+
+        # Config is the hash stored in a Process::TransitionAction's config key
         Config                   => {
             Owner => 'root@localhost',
             # or
@@ -68,13 +70,10 @@ sub new {
             UserID  => 123,                     # optional, to override the UserID from the logged user
         }
     );
-    Ticket contains the result of TicketGet including DynamicFields
-    Config is the Config Hash stored in a Process::TransitionAction's  Config key
-    Returns:
 
-    $TicketOwnerSetResult = 1; # 0
+Returns:
 
-    );
+    my $Success = 1; # 0
 
 =cut
 
