@@ -1,18 +1,21 @@
 # --
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
 # did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
-## nofilter(TidyAll::Plugin::OTRS::Perl::Pod::SpellCheck)
+## nofilter(TidyAll::Plugin::Znuny::Perl::LayoutObject)
 
 package Kernel::System::Util;
 
 use strict;
 use warnings;
 
+use utf8;
+
 use MIME::Base64;
+use Data::UUID;
 
 use Kernel::System::VariableCheck qw(:all);
 
@@ -75,6 +78,31 @@ sub IsITSMInstalled {
     return $Self->{ITSMInstalled};
 }
 
+=head2 IsITSMIncidentProblemManagementInstalled()
+
+Checks if ITSMIncidentProblemManagement is installed.
+
+    my $IsITSMIncidentProblemManagementInstalled = $UtilObject->IsITSMIncidentProblemManagementInstalled();
+
+    Returns 1 if ITSMIncidentProblemManagement is installed and 0 otherwise.
+
+=cut
+
+sub IsITSMIncidentProblemManagementInstalled {
+    my ( $Self, %Param ) = @_;
+
+    # Use cached result because it won't change within the process.
+    return $Self->{ITSMIncidentProblemManagementInstalled} if defined $Self->{ITSMIncidentProblemManagementInstalled};
+
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+
+    # Just use some arbitrary SysConfig option to check if IncidentProblemManagement is present.
+    $Self->{ITSMIncidentProblemManagementInstalled}
+        = $ConfigObject->Get('Frontend::Module')->{AgentITSMIncidentProblemManagement} ? 1 : 0;
+
+    return $Self->{ITSMIncidentProblemManagementInstalled};
+}
+
 =head2 IsFrontendContext()
 
 Checks if current code is being executed in frontend context, e.g. agent frontend.
@@ -257,6 +285,7 @@ sub GetInstalledDBCRUDObjects {
     my @FilePaths = $MainObject->DirectoryRead(
         Directory => $KernelSystemPath,
         Filter    => '*.pm',
+        Recursive => 1,
     );
 
     my @DBCRUDObjects;
@@ -272,7 +301,7 @@ sub GetInstalledDBCRUDObjects {
         next FILEPATH if ${$FileContentRef} !~ m{^package (.*?);$}m;
         my $DBCRUDPackage = $1;
         next FILEPATH if $DBCRUDPackage eq 'Kernel::System::DBCRUD';
-        next FILEPATH if $DBCRUDPackage eq 'Kernel::System::DBCRUDTest';
+        next FILEPATH if $DBCRUDPackage eq 'Kernel::System::UnitTest::DBCRUD';
 
         my $DBCRUDObject = $Kernel::OM->Get($DBCRUDPackage);
         next FILEPATH if !$DBCRUDObject;
@@ -283,4 +312,23 @@ sub GetInstalledDBCRUDObjects {
     return \@DBCRUDObjects;
 }
 
+=head2 CreateUUIDString()
+
+Returns a new UUID in text form, or undef if there was an error. Any arguments
+are passed through to Data::UUID::create_str(). Unlike Data::UUID, hex digits
+are lowercased to conform to RFC4122.
+
+=cut
+
+sub CreateUUIDString {
+    my ( $Self, @Param ) = @_;
+
+    # Create a Data::UUID object on demand and cache it for performance reasons.
+    # Init of Data::UUID takes a long time.
+    $Self->{DataUUID} //= Data::UUID->new();
+    return if !$Self->{DataUUID};
+
+    return lc $Self->{DataUUID}->create_str(@Param);
+}
+
 1;
